Future work
===========

- Add support for a competing hazard model. This would make it possible to analyze a dataset where there's multiple final outcomes.
- Add support for left-censoring. This would make it possible to analyze some great datasets such as `Washington Posts unsolved homicide dataset <https://github.com/washingtonpost/data-homicides>`_ where we don't know *when* a murder was dispositioned.
- Add support for multi-stage processes where there's a number of "milestones" that depend on each other.
- Add support for some kind of recurrent neural network or similar where the features can vary over time.


License
=======

Convoys uses the MIT license.

